@@ -223,7 +223,7 @@ def _get_hue_map(hbins = 16, start_hue = 0.0,
     return cmap
 
 def plot_tm30_cvg(spd, cri_type = 'ies-tm30',  
-                  gamut_line_color = 'r',
+                  gamut_line_color = None,
                   gamut_line_style = '-',
                   gamut_line_marker = 'o',
                   gamut_line_label = None,
@@ -260,8 +260,9 @@ def plot_tm30_cvg(spd, cri_type = 'ies-tm30',
             | 'r', optional
             | Plotting line style for the line connecting the 
             | average test chromaticity in the hue bins.
+            | None defaults to red (240,80,70)/255 (IES-TM30-20 recommended).
         :gamut_line_style:
-            | 'r', optional
+            | '-', optional
             | Plotting color for the line connecting the 
             | average test chromaticity in the hue bins.
         :gamut_line_marker:
@@ -305,13 +306,15 @@ def plot_tm30_cvg(spd, cri_type = 'ies-tm30',
             | dictionary with required parameters for plotting functions. 
     """
 
-    data = _tm30_process_spd(spd, cri_type = 'ies-tm30', **kwargs)
+    data = _tm30_process_spd(spd, cri_type = cri_type, **kwargs)
     hdata = data['hue_bin_data']
     
     # Normalized chroma (closed gamut):
     jabt = hdata['jabtn_hj_closed'][:,0,:]
     jabr = hdata['jabrn_hj_closed'][:,0,:]
     
+    if gamut_line_color is None: gamut_line_color = np.array((240,80,70))/255 # recommended color in ANSI/IES-TM30-20
+        
     # Plot color vector graphic
     _, axh, _ = plot_ColorVectorGraphic(jabt = jabt, jabr = jabr, 
                                         hbins = hdata['nhbins'], 
@@ -407,7 +410,7 @@ def plot_tm30_spd(spd, cri_type = 'ies-tm30', axh = None,
   
     """
 
-    data = _tm30_process_spd(spd, cri_type = 'ies-tm30',**kwargs)
+    data = _tm30_process_spd(spd, cri_type = cri_type,**kwargs)
     
     # Normalize Sr to same luminous power as spd:
     Phiv_spd = spd_to_power(data['St'], ptype = 'pu', cieobs = data['cri_type']['cieobs']['cct'])
@@ -469,7 +472,7 @@ def plot_tm30_Rfi(spd, cri_type = 'ies-tm30', axh = None,
         :data:
             | dictionary with required parameters for plotting functions.     
     """
-    data = _tm30_process_spd(spd, cri_type = 'ies-tm30',**kwargs)
+    data = _tm30_process_spd(spd, cri_type = cri_type,**kwargs)
 
     Rfi = data['Rfi']
     
@@ -552,7 +555,7 @@ def plot_tm30_Rfhj(spd, cri_type = 'ies-tm30', axh = None,
             | dictionary with required parameters for plotting functions.     
     """
     
-    data = _tm30_process_spd(spd, cri_type = 'ies-tm30',**kwargs)
+    data = _tm30_process_spd(spd, cri_type = cri_type,**kwargs)
     hdata = data['hue_bin_data']
     Rfhj = data['Rfhj']
         
@@ -647,7 +650,7 @@ def plot_tm30_Rcshj(spd, cri_type = 'ies-tm30', axh = None,
     """
 
     
-    data = _tm30_process_spd(spd, cri_type = 'ies-tm30',**kwargs)
+    data = _tm30_process_spd(spd, cri_type = cri_type,**kwargs)
     hdata = data['hue_bin_data']
     Rcshj = data['Rcshj']
     
@@ -746,7 +749,7 @@ def plot_tm30_Rhshj(spd, cri_type = 'ies-tm30', axh = None,
     """
 
     
-    data = _tm30_process_spd(spd, cri_type = 'ies-tm30',**kwargs)
+    data = _tm30_process_spd(spd, cri_type = cri_type,**kwargs)
     hdata = data['hue_bin_data']
     Rhshj = data['Rhshj']
 
@@ -835,7 +838,7 @@ def plot_tm30_Rxhj(spd, cri_type = 'ies-tm30', axh = None, figsize = (6,15),
             | dictionary with required parameters for plotting functions.     
     """
 
-    data = _tm30_process_spd(spd, cri_type = 'ies-tm30',**kwargs)
+    data = _tm30_process_spd(spd, cri_type = cri_type,**kwargs)
     
     if axh is None:
         fig, axh = plt.subplots(nrows = 3, ncols = 1, sharex = True, figsize = figsize)
@@ -1431,7 +1434,7 @@ def plot_cri_graphics(data, cri_type = None, hbins = 16, start_hue = 0.0, scalef
                                        scale_vf_chroma_to_sample_chroma = scale_vf_chroma_to_sample_chroma)
 
     # Unpack data dictionary:
-    (DEa, DEi, Rcshj, Rf,
+    (AnnexE_priority, DEa, DEi, Rcshj, Rf,
      Rfhj, Rfi, Rg, Rhshj, 
      Sr, St, cct, cri_type, 
      duv, hue_bin_data, vf,
@@ -1464,15 +1467,14 @@ def plot_cri_graphics(data, cri_type = None, hbins = 16, start_hue = 0.0, scalef
                
         
     for i in range(cct.shape[0]):
- 
         
         fig = plt.figure(figsize=(10, 6), dpi=144)
     
         # Plot CVG:
         ax_CVG = create_subplot(layout,1, polar = True, frameon = False)
         if plot_test_sample_coord == False:  
-            jabti = None
-            jabri = None
+            jabti_i = None
+            jabri_i = None
         else:
             jabti_i = jabti[...,i:i+1,:]
             jabri_i = jabri[...,i:i+1,:]
@@ -1488,8 +1490,8 @@ def plot_cri_graphics(data, cri_type = None, hbins = 16, start_hue = 0.0, scalef
                                                    scalef = scalef, 
                                                    force_CVG_layout = force_CVG_layout, 
                                                    bin_labels = '#',
-                                                   jabti = jabti, 
-                                                   jabri = jabri, 
+                                                   jabti = jabti_i, 
+                                                   jabri = jabri_i, 
                                                    hbinnr = hbinnr)
                 
         # Plot VF:
