@@ -60,7 +60,85 @@ __all__ = ['_get_hue_bin_data','spd_to_jab_t_r','spd_to_rg', 'spd_to_DEi',
            'optimize_scale_factor','spd_to_cri',
            '_hue_bin_data_to_rxhj', '_hue_bin_data_to_rfi', '_hue_bin_data_to_rg']
 
+_CCT_MODE = 'ohno2014'
 #------------------------------------------------------------------------------
+def _get_hue_bin_data_individual_samples(jabt,jabr, normalized_chroma_ref = 100):
+    """ Helper function to return dict with required keys when nhbins = None in call to _get_hue_bin_data"""
+    
+    # get hues of jabt, jabr:
+    ht = cam.hue_angle(jabt[...,1], jabt[...,2], htype = 'rad')
+    hr = cam.hue_angle(jabr[...,1], jabr[...,2], htype = 'rad')
+    
+    # Get chroma of jabt, jabr:
+    Ct = ((jabt[...,1]**2 + jabt[...,2]**2))**0.5
+    Cr = ((jabr[...,1]**2 + jabr[...,2]**2))**0.5
+    
+    
+    # Calculate DEi between jabt, jabr:
+    DEi = ((jabt - jabr)**2).sum(axis = -1, keepdims = True)**0.5
+    
+    jabt_hj, jabr_hj, DE_hj = jabt, jabr, DEi
+    
+    # some dummy variables:
+    start_hue = 0
+    dh = None
+    hue_bin_edges = None
+    nhbins = jabt.shape[0]
+    ht_idx, hr_idx = np.arange(nhbins)[:,None], np.arange(nhbins)[:,None]
+    
+    # calculate normalized hue-bin averages for jabt, jabr:
+    ht_hj = cam.hue_angle(jabt_hj[...,1],jabt_hj[...,2],htype='rad')
+    hr_hj = cam.hue_angle(jabr_hj[...,1],jabr_hj[...,2],htype='rad')
+    Ct_hj = ((jabt_hj[...,1]**2 + jabt_hj[...,2]**2))**0.5
+    Cr_hj = ((jabr_hj[...,1]**2 + jabr_hj[...,2]**2))**0.5
+    Ctn_hj = normalized_chroma_ref*Ct_hj/(Cr_hj + 1e-308) # calculate normalized chroma for samples under test
+    Ctn_hj[Cr_hj == 0.0] = np.inf
+    jabtn_hj = jabt_hj.copy()
+    jabrn_hj = jabr_hj.copy()
+    jabtn_hj[...,1], jabtn_hj[...,2] = Ctn_hj*np.cos(ht_hj), Ctn_hj*np.sin(ht_hj)
+    jabrn_hj[...,1], jabrn_hj[...,2] = normalized_chroma_ref*np.cos(hr_hj), normalized_chroma_ref*np.sin(hr_hj)
+    
+    # calculate normalized versions of jabt, jabr:
+    jabtn = jabt.copy()
+    jabrn = jabr.copy()
+    Ctn = np.zeros((jabt.shape[0],jabt.shape[1]))
+
+    Crn = Ctn.copy()
+    for j in range(nhbins):
+        Ctn = Ctn + (Ct/Cr_hj[j,...])*(hr_idx==j)
+        Crn = Crn + (Cr/Cr_hj[j,...])*(hr_idx==j)
+    Ctn*=normalized_chroma_ref
+    Crn*=normalized_chroma_ref
+
+    jabtn[...,1] = (Ctn*np.cos(ht))
+    jabtn[...,2] = (Ctn*np.sin(ht))
+    jabrn[...,1] = (Crn*np.cos(hr))
+    jabrn[...,2] = (Crn*np.sin(hr))
+
+    # closed jabt_hj, jabr_hj for Rg:
+    jabt_hj_closed = np.vstack((jabt_hj,jabt_hj[:1,...]))
+    jabr_hj_closed = np.vstack((jabr_hj,jabr_hj[:1,...]))
+    
+    # closed jabtn_hj, jabrn_hj for plotting:
+    jabtn_hj_closed = np.vstack((jabtn_hj,jabtn_hj[:1,...]))
+    jabrn_hj_closed = np.vstack((jabrn_hj,jabrn_hj[:1,...]))
+    
+    return {'jabt' : jabt, 'jabr' : jabr, 
+            'jabtn' : jabtn, 'jabrn' : jabrn,
+            'DEi' : DEi[...,0], 
+            'Ct' : Ct, 'Cr': Cr, 'ht' : ht, 'hr' : hr, 
+            'ht_idx' : ht_idx, 'hr_idx' : hr_idx,
+            'jabt_hj' : jabt_hj, 'jabr_hj' : jabr_hj, 'DE_hj' : DE_hj[...,0],
+            'jabt_hj_closed' : jabt_hj_closed, 'jabr_hj_closed' : jabr_hj_closed,
+            'jabtn_hj' : jabtn_hj, 'jabrn_hj' : jabrn_hj,
+            'jabtn_hj_closed' : jabtn_hj_closed, 'jabrn_hj_closed' : jabrn_hj_closed,
+            'ht_hj' : ht_hj, 'hr_hj' : hr_hj, 
+            'Ct_hj': Ct_hj, 'Cr_hj' : Cr_hj, 'Ctn_hj': Ctn_hj,
+            'nhbins' : nhbins, 'start_hue' : start_hue, 
+            'normalized_chroma_ref' : normalized_chroma_ref, 
+            'dh' : dh, 'hue_bin_edges' : hue_bin_edges, 
+            'hbinnrs' : hr_idx}
+    
 def _get_hue_bin_data(jabt, jabr, start_hue = 0, nhbins = 16,
                       normalized_chroma_ref = 100):
     """
@@ -108,10 +186,14 @@ def _get_hue_bin_data(jabt, jabr, start_hue = 0, nhbins = 16,
             | - 'hue_bin_edges': hue bin edge (rad)
             | - 'hbinnrs':  hue bin indices for each sample under ref. (= hr_idx)
     """
-    # calculate hue-bin width, edges:
-    dh = 360/nhbins 
-    hue_bin_edges = np.arange(start_hue, 360 + 1, dh)*np.pi/180
-
+    
+    if nhbins is None:
+        return _get_hue_bin_data_individual_samples(jabt,jabr,normalized_chroma_ref = normalized_chroma_ref)
+    else:
+        # calculate hue-bin width, edges:
+        dh = 360/nhbins 
+        hue_bin_edges = np.arange(start_hue, 360 + 1, dh)*np.pi/180
+        
     # get hues of jabt, jabr:
     ht = cam.hue_angle(jabt[...,1], jabt[...,2], htype = 'rad')
     hr = cam.hue_angle(jabr[...,1], jabr[...,2], htype = 'rad')
@@ -147,7 +229,8 @@ def _get_hue_bin_data(jabt, jabr, start_hue = 0, nhbins = 16,
         jabt_hj[j,...] = np.sum((jabt * cndr_hj[...,None]), axis=0)/wr.T # must use ref. bins !!!
         jabr_hj[j,...] = np.sum((jabr * cndr_hj[...,None]), axis=0)/wr.T
         DE_hj[j,...] = np.nansum((DEi * cndr_hj[...,None])/wr.T, axis = 0).T # local color difference is average of DEi per hue bin !!
-    
+        DE_hj[j,np.isnan(wr[0])] = np.nan # signal empty hue bins with a NaN
+        
     # calculate normalized hue-bin averages for jabt, jabr:
     ht_hj = cam.hue_angle(jabt_hj[...,1],jabt_hj[...,2],htype='rad')
     hr_hj = cam.hue_angle(jabr_hj[...,1],jabr_hj[...,2],htype='rad')
@@ -265,9 +348,10 @@ def _hue_bin_data_to_rxhj(hue_bin_data, cri_type = _CRI_TYPE_DEFAULT,
             | Dict with hue bin data obtained with _get_hue_bin_data().
         :use_bin_avg_DEi: 
             | True, optional
-            | Note that following IES-TM30 DEi from gamut_slicer() is obtained by
+            | Note that following IES-TM30 DEhj from gamut_slicer() is obtained by
             | averaging the DEi per hue bin (True), and NOT by averaging the 
-            | jabt and jabr per hue  bin and then calculating the DEi (False).
+            | jabt and jabr per hue  bin and then calculating the DEhj (False).
+            | If None: use value in rg_pars dict in cri_type dict!
         :scale_fcn:
             | function handle to type of cri scale, 
             | e.g. 
@@ -287,7 +371,7 @@ def _hue_bin_data_to_rxhj(hue_bin_data, cri_type = _CRI_TYPE_DEFAULT,
         <https://www.ies.org/store/technical-memoranda/ies-method-for-evaluating-light-source-color-rendition/>`_
     """
     
-    if (scale_factor is None) | (scale_fcn is None):
+    if (scale_factor is None) | (scale_fcn is None) | (use_bin_avg_DEi is None):
         if isinstance(cri_type, str): 
            args = copy.deepcopy(locals()) # get dict with keyword input arguments to function (used to overwrite non-None input arguments present in cri_type dict)
            cri_type = process_cri_type_input(cri_type, args, callerfunction = 'cri._hue_bin_data_to_Ri')
@@ -299,6 +383,10 @@ def _hue_bin_data_to_rxhj(hue_bin_data, cri_type = _CRI_TYPE_DEFAULT,
         if (scale_fcn is None):
             scale_fcn = cri_type['scale']['fcn']    
         
+        if (use_bin_avg_DEi is None) & ('rg_pars' in cri_type): 
+            use_bin_avg_DEi = cri_type['rg_pars']['use_bin_avg_DEi']
+        else:
+            raise Exception('Define use_bin_avg_DEi in rg_pars dict in cri_type dict or set use_bin_avg_DEi kwarg to not None!')
 
     nhbins = hue_bin_data['nhbins']
     start_hue = hue_bin_data['start_hue']
@@ -580,7 +668,7 @@ def spd_to_jab_t_r(St, cri_type = _CRI_TYPE_DEFAULT, out = 'jabt,jabr',
     # unpack and update dict with parameters:
     (avg, catf, cieobs,
      cri_specific_pars, cspace, 
-     ref_type, rg_pars, sampleset, scale) = [cri_type[x] for x in sorted(cri_type.keys())] 
+     ref_type, rf_from_avg_rounded_rfi, rg_pars, sampleset, scale) = [cri_type[x] for x in sorted(cri_type.keys())] 
 
     # pre-interpolate SPD:
     if wl is not None: 
@@ -595,7 +683,8 @@ def spd_to_jab_t_r(St, cri_type = _CRI_TYPE_DEFAULT, out = 'jabt,jabr',
     xyztw_cct = spd_to_xyz(St, cieobs = cieobs['cct'], rfl = None, out = 1)
 
     # A.b. get cct:
-    cct, duv = xyz_to_cct(xyztw_cct, cieobs = cieobs['cct'], out = 'cct,duv',mode = 'lut')
+    cct, duv = xyz_to_cct(xyztw_cct, cieobs = cieobs['cct'], out = 'cct,duv',mode = _CCT_MODE)
+    cct = np.abs(cct) # out-of-lut ccts are encoded as negative
     
     # A.c. get reference ill.:
     if isinstance(ref_type,np.ndarray):
@@ -605,7 +694,7 @@ def spd_to_jab_t_r(St, cri_type = _CRI_TYPE_DEFAULT, out = 'jabt,jabr',
 
     # B. calculate xyz and xyzw of SPD and Sr (stack for speed):
     xyzi, xyzw = spd_to_xyz(np.vstack((St,Sr[1:])), cieobs = cieobs['xyz'], rfl = sampleset, out = 2)
-    xyzri, xyzrw = spd_to_xyz(Sr, cieobs = cieobs['xyz'], rfl = sampleset, out = 2)
+    #xyzri, xyzrw = spd_to_xyz(Sr, cieobs = cieobs['xyz'], rfl = sampleset, out = 2)
     N = St.shape[0]-1
     xyzti, xyzri =  xyzi[:,:N,:], xyzi[:,N:,:]
     xyztw, xyzrw =  xyzw[:N,:], xyzw[N:,:]
@@ -788,7 +877,7 @@ def spd_to_DEi(St, cri_type = _CRI_TYPE_DEFAULT, out = 'DEi', wl = None, \
 
 
 #------------------------------------------------------------------------------
-def optimize_scale_factor(cri_type, opt_scale_factor, scale_fcn, avg) :
+def optimize_scale_factor(cri_type, opt_scale_factor, scale_fcn, avg, rf_from_avg_rounded_rfi) :
     """
     Optimize scale_factor of cri-model in cri_type 
     such that average Rf for a set of light sources is the same as that 
@@ -840,32 +929,59 @@ def optimize_scale_factor(cri_type, opt_scale_factor, scale_fcn, avg) :
         scale_fcn_opt = opt_cri_type ['scale']['fcn']
         scale_factor_opt = opt_cri_type ['scale']['cfactor']
         avg_opt = opt_cri_type ['avg']
-        DEa_opt = spd_to_DEi(opt_spd_set, out ='DEa', cri_type = opt_cri_type) # DEa using target cri
-        Rf_opt = avg(scale_fcn_opt(DEa_opt,scale_factor_opt))
         
-        DEa = spd_to_DEi(opt_spd_set, out ='DEa', cri_type = cri_type) # DEa using current cri
-
+        rf_from_avg_rounded_rfi_opt = opt_cri_type['rf_from_avg_rounded_rfi']
+        rf_from_avg_rounded_rfi = cri_type['rf_from_avg_rounded_rfi']
         
+        if not rf_from_avg_rounded_rfi_opt:
+            DEa_opt = spd_to_DEi(opt_spd_set, out ='DEa', cri_type = opt_cri_type) # DEa using target cri
+            Rf_opt = avg(scale_fcn_opt(DEa_opt,scale_factor_opt))
+            
+        else:
+            DEi_opt = spd_to_DEi(opt_spd_set, out ='DEi', cri_type = opt_cri_type) # DEa using target cri
+            Rfi_opt = avg(np.round(scale_fcn_opt(DEi_opt,scale_factor_opt),0)) # average rounded individual Rfi to get Rf !!!
+            Rf_opt = avg(Rfi_opt)
+            
+        if not rf_from_avg_rounded_rfi:
+            DEa = spd_to_DEi(opt_spd_set, out ='DEa', cri_type = cri_type) # DEa using current cri
+        else:
+            DEi = spd_to_DEi(opt_spd_set, out ='DEi', cri_type = cri_type) # DEa using target cri
+                        
+            
         # optimize scale_factor to minimize rms difference:
         sf = cri_type['scale']['cfactor'] # get scale_factor of cri_type to determine len and non-optimized factors
-
+        
+        if sf is None: sf = [None]
+        
         if (isinstance(sf,float)): #(isinstance(1.0*sf,float))
             sf = [sf]
         if isinstance(opt_scale_factor, bool):
             opt_scale_factor = [opt_scale_factor] 
+            
         if (len(opt_scale_factor)==1) & (len(sf) == 1):
             x0 = 1
-            optfcn = lambda x : math.rms(avg(scale_fcn(DEa,x)) - Rf_opt,axis=1) # optimize the only cfactor
+            if not rf_from_avg_rounded_rfi:
+                optfcn = lambda x : math.rms(avg(scale_fcn(DEa,x)) - Rf_opt,axis=1) # optimize the only cfactor
+            else:
+                optfcn = lambda x : math.rms(avg(avg(np.round(scale_fcn(DEi, x),0))) - Rf_opt,axis=1)
+       
         elif (len(opt_scale_factor)==1) & (len(sf) > 1):     
             x0 = 1
-            optfcn = lambda x : math.rms(avg(scale_fcn(DEa,np.hstack( (x,sf[1:]) ))) - Rf_opt,axis=1) # optimize the first cfactor (for scale_factor input of len = 1)
+            if not rf_from_avg_rounded_rfi: 
+                optfcn = lambda x : math.rms(avg(scale_fcn(DEa,np.hstack( (x,sf[1:]) ))) - Rf_opt,axis=1) # optimize the first cfactor (for scale_factor input of len = 1)
+            else:
+                optfcn = lambda x : math.rms(avg(avg(np.round(scale_fcn(DEi,np.hstack( (x,sf[1:]) )),0))) - Rf_opt,axis=1) # optimize the first cfactor (for scale_factor input of len = 1)
+
         else:
             x0 = np.ones(np.sum(opt_scale_factor))
-            optfcn = lambda x : math.rms(avg(scale_fcn(DEa,np.hstack( (x,sf[np.invert(opt_scale_factor)]) ))) - Rf_opt,axis=1) # optimize first N 'True' cfactor (for scale_factor input of len = n>=N)
+            if not rf_from_avg_rounded_rfi: 
+                optfcn = lambda x : math.rms(avg(scale_fcn(DEa,np.hstack( (x,sf[np.invert(opt_scale_factor)]) ))) - Rf_opt,axis=1) # optimize first N 'True' cfactor (for scale_factor input of len = n>=N)
+            else: 
+                optfcn = lambda x : math.rms(avg(avg(np.round(scale_fcn(DEa,np.hstack( (x,sf[np.invert(opt_scale_factor)]) )),0))) - Rf_opt,axis=1) # optimize first N 'True' cfactor (for scale_factor input of len = n>=N)
         
         optresult = sp.optimize.minimize(fun = optfcn, x0 = x0, args=(), method = 'Nelder-Mead')
         scale_factor = optresult['x']
-        
+
         #Reconstruct 'scale_factor' from optimized and fixed parts:
         if (len(opt_scale_factor)==1) & (len(sf) == 1):
             pass #only cfactor
@@ -978,6 +1094,11 @@ def spd_to_rg(St, cri_type = _CRI_TYPE_DEFAULT, out = 'Rg', wl = None, \
             |    - key: 'normalized_chroma_ref': 100.0 or float, optional
             |                Controls the size (chroma/radius) 
             |                of the normalization circle/gamut.
+            |    - key 'use_bin_avg_DEi': True or False
+            |               Note that following IES-TM30 DEhj from gamut_slicer()
+            |               is obtained by averaging the DEi per hue bin (True),
+            |               and NOT by averaging the jabt and jabr per hue bin 
+            |               and then calculating the DEhj (False).
         :avg: 
             | None or fcn handle, optional
             | Averaging function (handle) for color differences, DEi 
@@ -1038,7 +1159,7 @@ def spd_to_rg(St, cri_type = _CRI_TYPE_DEFAULT, out = 'Rg', wl = None, \
     args = copy.deepcopy(locals()) # get dict with keyword input arguments to function (used to overwrite non-None input arguments present in cri_type dict)
     cri_type = process_cri_type_input(cri_type, args, callerfunction = 'cri.spd_to_rg')
 
-    #avg, catf, cieobs, cieobs_cct, cri_specific_pars, cspace, cspace_pars, ref_type, rg_pars, sampleset, scale_factor, scale_fcn = [cri_type[x] for x in sorted(cri_type.keys())] 
+    #avg, catf, cieobs, cieobs_cct, cri_specific_pars, cspace, cspace_pars, ref_type, rf_from_avg_rounded_rfi, rg_pars, sampleset, scale_factor, scale_fcn = [cri_type[x] for x in sorted(cri_type.keys())] 
 
        
     # calculate Jabt of test and Jabr of the reference illuminant corresponding to test: 
@@ -1050,8 +1171,9 @@ def spd_to_rg(St, cri_type = _CRI_TYPE_DEFAULT, out = 'Rg', wl = None, \
                                           out = 'jabt,jabr,xyzti,xyztw,xyzri,xyzrw,xyztw_cct,cct,duv,St,Sr') 
 
     # calculate gamut area index:
-    rg_pars = cri_type['rg_pars']
-    nhbins, normalize_gamut, normalized_chroma_ref, start_hue  = [rg_pars[x] for x in sorted(rg_pars.keys())]
+    rg_pars = cri_type['rg_pars'] 
+    if 'use_bin_avg_DEi' not in rg_pars: rg_pars['use_bin_avg_DEi'] = True
+    nhbins, normalize_gamut, normalized_chroma_ref, start_hue, use_bin_avg_DEi  = [rg_pars[x] for x in sorted(rg_pars.keys())]
     
     # get hue_bin_data:
     hue_bin_data = _get_hue_bin_data(jabt, jabr, 
@@ -1088,7 +1210,8 @@ def spd_to_rg(St, cri_type = _CRI_TYPE_DEFAULT, out = 'Rg', wl = None, \
     
 #------------------------------------------------------------------------------
 def spd_to_cri(St, cri_type = _CRI_TYPE_DEFAULT, out = 'Rf', wl = None, \
-               sampleset = None, ref_type = None, cieobs = None, avg = None, \
+               sampleset = None, ref_type = None, cieobs = None, \
+               avg = None, rf_from_avg_rounded_rfi = None,\
                scale = None, opt_scale_factor = False, cspace = None, catf = None,\
                cri_specific_pars = None, rg_pars = None, fit_gamut_ellipse = False):
     """
@@ -1173,7 +1296,8 @@ def spd_to_cri(St, cri_type = _CRI_TYPE_DEFAULT, out = 'Rf', wl = None, \
             |             luxpy.cri._CRI_DEFAULTS['mcri']['cri_specific_pars']
         :rg_pars: 
             | None or dict, optional
-            | Dict containing specifying parameters for slicing the gamut.
+            | Dict containing specifying parameters for slicing the gamut 
+            | and calculating hue bin specific indices.
             | Dict structure: 
             |     {'nhbins' : None, 'start_hue' : 0, 
             |       'normalize_gamut' : False, 'normalized_chroma_ref': 100.0}
@@ -1186,11 +1310,22 @@ def spd_to_cri(St, cri_type = _CRI_TYPE_DEFAULT, out = 'Rf', wl = None, \
             |    - key: 'normalized_chroma_ref': 100.0 or float, optional
             |                Controls the size (chroma/radius) 
             |                of the normalization circle/gamut.
+            |    - key 'use_bin_avg_DEi': True or False
+            |               Note that following IES-TM30 DEhj from gamut_slicer()
+            |               is obtained by averaging the DEi per hue bin (True),
+            |               and NOT by averaging the jabt and jabr per hue bin 
+            |               and then calculating the DEhj (False).
         :avg: 
             | None or fcn handle, optional
             | Averaging function (handle) for color differences, DEi 
             | (e.g. numpy.mean, .math.rms, .math.geomean)
             | None use the one specified in :cri_type: dict.
+        :rf_from_avg_rounded_rfi:
+            | None, optional
+            | If None: use as specified in the :cri_type: dict
+            | If False: calculate Rf directly from DEa.
+            | If True: round Rfi to integer numbers and average them to Rf
+            |           (method used in CIE-13.3-1995 Ra calculation)
         :scale:
             | None or dict, optional
             | Specifies scaling of color differences to obtain CRI.
@@ -1198,7 +1333,7 @@ def spd_to_cri(St, cri_type = _CRI_TYPE_DEFAULT, out = 'Rf', wl = None, \
             |     - dict: user specified dict with scaling parameters.
             |         - key: 'fcn': function handle to type of cri scale, 
             |                 e.g. 
-            |                 * linear()_scale --> (100 - scale_factor*DEi), 
+            |                 * linear_scale --> (100 - scale_factor*DEi), 
             |                 * log_scale --> (cfr. Ohno's CQS), 
             |                 * psy_scale (Smet et al.'s cri2012,See: LRT 2013)
             |        - key: 'cfactor': factors used in scaling function, 
@@ -1289,9 +1424,10 @@ def spd_to_cri(St, cri_type = _CRI_TYPE_DEFAULT, out = 'Rf', wl = None, \
         scale_factor = cri_type['scale']['cfactor']
     scale_fcn = cri_type['scale']['fcn']
     avg = cri_type['avg']  
+    rf_from_avg_rounded_rfi = cri_type['rf_from_avg_rounded_rfi']
     
     # Input parsing: optimize scale_factor for input based on F1-F12 (default) if scale_factor is NaN or None:
-    scale_factor = optimize_scale_factor(cri_type,opt_scale_factor, scale_fcn, avg)
+    scale_factor = optimize_scale_factor(cri_type,opt_scale_factor, scale_fcn, avg, rf_from_avg_rounded_rfi)
 
     if np.isnan(scale_factor).any():
         raise Exception ('Unable to optimize scale_factor.')
@@ -1311,15 +1447,19 @@ def spd_to_cri(St, cri_type = _CRI_TYPE_DEFAULT, out = 'Rf', wl = None, \
     
     # B. convert DEi to color rendering index:
     Rfi = scale_fcn(DEi, scale_factor)
-    Rf = np2d(scale_fcn(DEa, scale_factor))
+    if not rf_from_avg_rounded_rfi:
+        Rf = np2d(scale_fcn(DEa, scale_factor))
+    else:
+        Rf = np2d(avg(np.round(Rfi,0),axis=0)) # as in CIE 13.3-1995 Ra calculation !!! 
     
     # C. get binned jabt jabr and DEi:
     if ('Rg' in outlist) | ('Rfhj' in outlist) | ('DEhj' in outlist) | \
        ('Rhshj' in outlist) | ('Rcshj' in outlist) | ('hue_bin_data' in outlist) |\
-       (fit_gamut_ellipse == True):
+       ('data' in outlist) | (fit_gamut_ellipse == True):
         
         rg_pars = cri_type['rg_pars'] 
-        nhbins, normalize_gamut, normalized_chroma_ref, start_hue  = [rg_pars[x] for x in sorted(rg_pars.keys())]
+        if 'use_bin_avg_DEi' not in rg_pars: rg_pars['use_bin_avg_DEi'] = True
+        nhbins, normalize_gamut, normalized_chroma_ref, start_hue, use_bin_avg_DEi  = [rg_pars[x] for x in sorted(rg_pars.keys())]
 
         
         # get hue_bin_data:
@@ -1342,7 +1482,11 @@ def spd_to_cri(St, cri_type = _CRI_TYPE_DEFAULT, out = 'Rf', wl = None, \
 
     # D. # Calculate local fidelity, chroma shifts and hue shifts:
     if hue_bin_data is not None:
-        Rcshj, Rhshj, Rfhj, DEhj = _hue_bin_data_to_rxhj(hue_bin_data)
+        Rcshj, Rhshj, Rfhj, DEhj = _hue_bin_data_to_rxhj(hue_bin_data, 
+                                                         scale_fcn = scale_fcn,
+                                                         scale_factor = scale_factor,
+                                                         cri_type = cri_type,
+                                                         use_bin_avg_DEi = use_bin_avg_DEi)
 
 
     if 'data' in out:
