@@ -19,6 +19,8 @@
 Module with functions related to plotting of color data
 =======================================================
 
+ :get_cmap(): Get an ndarray of rgb values representing a linearly sampled matplotlib colormap
+
  :get_subplot_layout(): Calculate layout of multiple subplots.
      
  :plot_color_data(): Plot color data (local helper function)
@@ -65,12 +67,32 @@ Module with functions related to plotting of color data
 from luxpy import math, _CIEOBS, _CSPACE, _CSPACE_AXES, _CIE_ILLUMINANTS, _CMF, _CIE_D65, daylightlocus, colortf, Yxy_to_xyz, spd_to_xyz, cri_ref, xyz_to_srgb
 from luxpy.utils import np, plt,_EPS, asplit
 from matplotlib.patches import Polygon
+from matplotlib import cm
 
-__all__ = ['get_subplot_layout','plotSL','plotDL','plotBB','plot_color_data',
+__all__ = ['get_cmap','get_subplot_layout','plotSL','plotDL','plotBB','plot_color_data',
            'plotceruleanline','plotUH','plotcircle','plotellipse',
            'plot_chromaticity_diagram_colors','plot_spectrum_colors',
            'plot_rfl_color_patches','plot_rgb_color_patches','plot_cmfs']
 
+def get_cmap(N, cmap_name = 'jet'):
+    """
+    Get an ndarray of rgba values representing a linearly sampled matplotlib colormap.
+    
+    Args:
+        :N:
+            | Number of rgba values in returned cmap.
+        :cmap_name:
+            | 'jet', optional
+            | Matplotlib color map name to sample from.
+            
+    Returns:
+        :cmap:
+            | ndarray with rgba values.
+    """
+    cmap = cm.get_cmap(cmap_name, N)
+    cmap = cmap(range(N))
+    return cmap
+
 def get_subplot_layout(N, min_1xncols = 3):
     """
     Calculate layout of multiple subplots.
@@ -171,7 +193,7 @@ def plotDL(ccts = None, cieobs =_CIEOBS, cspace = _CSPACE, axh = None, \
     Args: 
         :ccts: 
             | None or list[float], optional
-            | None defaults to [4000 K to 1e19 K] in 100 steps on a log10 scale.
+            | None defaults to [4000 K to 1e11 K] in 100 steps on a log10 scale.
         :force_daylight_below4000K: 
             | False or True, optional
             | CIE daylight phases are not defined below 4000 K. 
@@ -208,7 +230,7 @@ def plotDL(ccts = None, cieobs =_CIEOBS, cspace = _CSPACE, axh = None, \
     """
     
     if ccts is None:
-        ccts = 10**np.linspace(np.log10(4000.0),np.log10(10.0**19.0),100)
+        ccts = 10**np.linspace(np.log10(4000.0),np.log10(10.0**11.0),100)
         
     xD,yD = daylightlocus(ccts, cieobs = cieobs, force_daylight_below4000K = force_daylight_below4000K)
     Y = 100*np.ones(xD.shape)
@@ -231,7 +253,7 @@ def plotBB(ccts = None, cieobs =_CIEOBS, cspace = _CSPACE, axh = None, cctlabels
             | None defaults to [1000 to 1e19 K].
             | Range: 
             |     [1000,1500,2000,2500,3000,3500,4000,5000,6000,8000,10000] 
-            |    + [15000 K to 1e19 K] in 100 steps on a log10 scale
+            |    + [15000 K to 1e11 K] in 100 steps on a log10 scale
         :cctlabels:
             | True or False, optional
             | Add cct text labels at various points along the blackbody locus.
@@ -267,7 +289,7 @@ def plotBB(ccts = None, cieobs =_CIEOBS, cspace = _CSPACE, axh = None, cctlabels
     """
     if ccts is None:
         ccts1 = np.array([1000.0,1500.0,2000.0,2500.0,3000.0,3500.0,4000.0,5000.0,6000.0,8000.0,10000.0])
-        ccts2 = 10**np.linspace(np.log10(15000.0),np.log10(10.0**19.0),100)
+        ccts2 = 10**np.linspace(np.log10(15000.0),np.log10(10.0**11.0),100)
         ccts = np.hstack((ccts1,ccts2))
     else:
         ccts1 = None
