@@ -131,7 +131,7 @@ def _triangle_mixer(Yxy_target, Yxyi, triangle_strengths):
         for i in range(N):
             M[:,i] = np.nansum(np.nansum(M_final*(combos == i)[None,...],axis=1),axis=-1)#/n_in_gamut
     else:
-        M = M3
+        M = M3[:,0,:]
     M[M.sum(axis=-1)==0] = np.nan
     return M
 
@@ -1455,7 +1455,9 @@ if __name__ == '__main__':
     
     def spd_to_cct(spd):
         xyz = lx.spd_to_xyz(spd,cieobs=cieobs)
-        return xyz_to_cct(xyz,cieobs=cieobs,out='cct,duv')[0]
+        cct, duv = xyz_to_cct(xyz,cieobs=cieobs,out='cct,duv')[0]
+        cct = np.abs(cct) # out-of-lut ccts are encoded as negative
+        return cct, duv
     
     #--------------------------------------------------------------------------
     if run_example_class_1 == True:
